@@ -24,7 +24,6 @@
 #include <rsvg.h>
 #include <stdlib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk-pixbuf/gdk-pixbuf-io.h>
 #include "rsvg-private.h"
 
 typedef struct {
@@ -54,7 +53,7 @@ rsvg_propegate_error (GError ** err,
 {
         if (err) {
                 *err = NULL;
-                g_set_error (err, rsvg_error_quark (), code, reason);
+                g_set_error (err, rsvg_error_quark (), code, "%s", reason);
         }
 }
 
@@ -163,7 +162,7 @@ gdk_pixbuf__svg_image_stop_load (gpointer data, GError **error)
                 result = FALSE;
         }
 
-        g_object_unref (G_OBJECT(context->handle));
+        g_object_unref (context->handle);
         g_free (context);
 
         return TRUE;
@@ -258,4 +257,5 @@ fill_info (GdkPixbufFormat *info)
         info->mime_types  = mime_types;
         info->extensions  = extensions;
         info->flags       = GDK_PIXBUF_FORMAT_SCALABLE;
+        info->license     = "LGPL";
 }
