@@ -1,4 +1,5 @@
-/* vim: set sw=4 sts=4: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* vim: set sw=4 sts=4 ts=4 expandtab: */
 /* 
    rsvg.h: SAX-based renderer for SVG files into a GdkPixbuf.
  
@@ -25,6 +26,9 @@
 #ifndef RSVG_H
 #define RSVG_H
 
+#include <glib-object.h>
+#include <gio/gio.h>
+
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 G_BEGIN_DECLS
@@ -77,24 +81,24 @@ struct _RsvgHandle {
 /* RsvgDimensionData
  */
 struct _RsvgDimensionData {
-        /**
-	 * SVG's width, in pixels
-	 */
+    /**
+     * SVG's width, in pixels
+     */
     int width;
 
-        /**
-	 * SVG's height, in pixels
-	 */
+    /**
+     * SVG's height, in pixels
+     */
     int height;
 
-        /**
-	 * em
-	 */
+    /**
+     * em
+     */
     gdouble em;
 
-        /**
-	 * ex
-	 */
+    /**
+     * ex
+     */
     gdouble ex;
 };
 
@@ -117,13 +121,13 @@ void rsvg_handle_set_dpi_x_y	(RsvgHandle * handle, double dpi_x, double dpi_y);
 
 RsvgHandle  *rsvg_handle_new		(void);
 gboolean     rsvg_handle_write		(RsvgHandle * handle, const guchar * buf, 
-					 gsize count, GError ** error);
+                                     gsize count, GError ** error);
 gboolean     rsvg_handle_close		(RsvgHandle * handle, GError ** error);
 GdkPixbuf   *rsvg_handle_get_pixbuf	(RsvgHandle * handle);
 GdkPixbuf   *rsvg_handle_get_pixbuf_sub (RsvgHandle * handle, const char *id);
 
 G_CONST_RETURN char	*rsvg_handle_get_base_uri (RsvgHandle * handle);
-void			 rsvg_handle_set_base_uri (RsvgHandle * handle, const char *base_uri);
+void                 rsvg_handle_set_base_uri (RsvgHandle * handle, const char *base_uri);
 
 void rsvg_handle_get_dimensions (RsvgHandle * handle, RsvgDimensionData * dimension_data);
 
@@ -132,6 +136,31 @@ gboolean rsvg_handle_get_position_sub (RsvgHandle * handle, RsvgPositionData * p
 
 gboolean rsvg_handle_has_sub (RsvgHandle * handle, const char *id);
 
+/* GIO APIs */
+
+typedef enum {
+    RSVG_HANDLE_FLAGS_NONE        = 0,
+} RsvgHandleFlags;
+
+void        rsvg_handle_set_base_gfile (RsvgHandle *handle,
+                                        GFile      *base_file);
+
+gboolean    rsvg_handle_read_stream_sync (RsvgHandle   *handle,
+                                          GInputStream *stream,
+                                          GCancellable *cancellable,
+                                          GError      **error);
+
+RsvgHandle *rsvg_handle_new_from_gfile_sync (GFile          *file,
+                                             RsvgHandleFlags flags,
+                                             GCancellable   *cancellable,
+                                             GError        **error);
+
+RsvgHandle *rsvg_handle_new_from_stream_sync (GInputStream   *input_stream,
+                                              GFile          *base_file,
+                                              RsvgHandleFlags flags,
+                                              GCancellable   *cancellable,
+                                              GError        **error);
+
 /* Accessibility API */
 
 G_CONST_RETURN char *rsvg_handle_get_title	(RsvgHandle * handle);
@@ -160,22 +189,22 @@ void rsvg_handle_free (RsvgHandle * handle);
  */
 typedef void (*RsvgSizeFunc) (gint * width, gint * height, gpointer user_data);
 void rsvg_handle_set_size_callback (RsvgHandle * handle,
-				    RsvgSizeFunc size_func,
-				    gpointer user_data, GDestroyNotify user_data_destroy);
+                                    RsvgSizeFunc size_func,
+                                    gpointer user_data, GDestroyNotify user_data_destroy);
 
 /* GdkPixbuf convenience API */
 
-GdkPixbuf *rsvg_pixbuf_from_file		(const gchar * file_name, GError ** error);
-GdkPixbuf *rsvg_pixbuf_from_file_at_zoom	(const gchar * file_name,
-						 double x_zoom, double y_zoom, GError ** error);
-GdkPixbuf *rsvg_pixbuf_from_file_at_size	(const gchar * file_name, gint width, gint height, 
-						 GError ** error);
-GdkPixbuf *rsvg_pixbuf_from_file_at_max_size	(const gchar * file_name,
-						 gint max_width, gint max_height, GError ** error);
+GdkPixbuf *rsvg_pixbuf_from_file            (const gchar * file_name, GError ** error);
+GdkPixbuf *rsvg_pixbuf_from_file_at_zoom    (const gchar * file_name,
+                                             double x_zoom, double y_zoom, GError ** error);
+GdkPixbuf *rsvg_pixbuf_from_file_at_size    (const gchar * file_name, gint width, gint height,
+                                             GError ** error);
+GdkPixbuf *rsvg_pixbuf_from_file_at_max_size    (const gchar * file_name,
+                                                 gint max_width, gint max_height, GError ** error);
 GdkPixbuf *rsvg_pixbuf_from_file_at_zoom_with_max (const gchar * file_name,
-						   double x_zoom,
-						   double y_zoom,
-						   gint max_width, gint max_height, GError ** error);
+                                                   double x_zoom,
+                                                   double y_zoom,
+                                                   gint max_width, gint max_height, GError ** error);
 
 #endif                          /* RSVG_DISABLE_DEPRECATED */
 
